@@ -42,7 +42,8 @@ class AdminInvoices(admin.ModelAdmin):
             subtotal = float(subtotal) + float(line.amount)
         obj.subtotal = subtotal
         obj.subtotal_iva = obj.subtotal * float(obj.taxes.value)
-        obj.total = obj.subtotal + obj.subtotal_iva
+        obj.subtotal_retentions = obj.subtotal * float(obj.retentions.value) * -1
+        obj.total = obj.subtotal + obj.subtotal_iva + obj.subtotal_retentions
         obj.save()
 
 class AdminReceivedInvoices(admin.ModelAdmin):
